modules.rst
==========

The MASA project is organized into several key modules, each responsible for different aspects of the system's functionality. Below is an overview of these modules:

.. toctree::
   :maxdepth: 2

   modules/index

